selfDir_3d1bc249 := $(dir $(lastword $(MAKEFILE_LIST)))

vegxMaps := $(wildcard map.VegX.*.csv)
vegbienMaps := $(subst .VegX.,.VegBIEN.,$(vegxMaps))

root := ../..
bin := $(root)/bin
mappings := $(root)/mappings
map := $(root)/map
map2vegbien := env out_database=vegbien $(map)

#####

all: _not_file # empty rule since must be first target in file

.SUFFIXES:

_not_file:
.PHONY: _not_file

all := $(wildcard output.*) $(vegbienMaps)

clean: _not_file
	$(RM) $(all)

#####

reinstall: _not_file uninstall install

#####

map.VegBIEN.%.csv: map.VegX.%.csv
	$(bin)/join_sort <$< $(mappings)/VegX-VegBIEN.$(*F).csv >$@
.PRECIOUS: map.VegBIEN.%.csv

#####

ifdef db

ifndef dbEngine
$(error dbEngine variable must be set. Possible values: MySQL, PostgreSQL)
endif

mapEnv := in_engine=$(dbEngine) in_database=$(db)

all: _not_file $(vegbienMaps:map.VegBIEN.%.csv=import-%)

import-%: map.VegBIEN.%.csv _not_file
	env $(mapEnv) $(map2vegbien) $<

##

install: _not_file db

uninstall: _not_file rm_db

bienPassword := $(shell cat $(root)/config/bien_password)
mysql := mysql --user=root --password='$(bienPassword)'

db: $(db).sql _not_file
	-$(mysql) <$<
	echo "GRANT SELECT ON $(db).* TO 'bien'@'localhost';"|$(mysql)
# ignore errors in db import so that GRANT will still be run

rm_db: _not_file
	-echo "REVOKE ALL ON $(db).* FROM 'bien'@'localhost';"|$(mysql)
	echo "DROP DATABASE IF EXISTS $(db);"|$(mysql)
# ignore errors about no such grant being defined

#####

else
$(error db variable must be set)
endif
